calc_dist: Calculate a distance data frame

Description Usage Arguments Value

View source: R/calc_dist.R

Description

Switchman function that forwards to a specific distance function or uses a custom distance method.

Usage

1
calc_dist(data, fun = "heom", trans = "range")

Arguments

data

Data frame.

fun

The distance calculation method, either as a string or as custom function.

trans

Optional transformation before distance calculation as string or custom function.

Value

nxn distance data frame


unmnn/evoxploit documentation built on Oct. 28, 2020, 12:24 p.m.