Description Usage Arguments Value
Switchman function that forwards to a specific distance function or uses a custom distance method.
1 |
data |
Data frame. |
fun |
The distance calculation method, either as a string or as custom function. |
trans |
Optional transformation before distance calculation as string or custom function. |
nxn distance data frame
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.